import numpy as np 
import scipy
import pandas as pd
import random
import astropy 
from numpy.linalg import inv, det, solve, cond
from tqdm import tqdm

import matplotlib.pyplot as plt
import matplotlib

import jax
import jax.numpy as jnp
from jax import grad, jit, vmap

"""
Function that builds cadence vs orbital period sensitivity map
"""

"""
Function that builds observing baseline vs consecutive-on-nights sensitivity map
"""

"""
Function that overlays observations on top of RV model for visualization and troubleshooting
"""

def calculate_rv(m1, m2, P, e=0, i=np.pi/2):
    """
    Calculate radial velocity semi-amplitude, K, based on planet and stellar parameters
    Eqn 14 from Lovis & Fischer 2010 
    (http://exoplanets.astro.yale.edu/workshop/EPRV/Bibliography_files/Radial_Velocity.pdf)
    
    Inputs:
    - m1: primary (stellar) mass [Solar mass]
    - m2: secondary (planet) mass [Earth mass]
    - P: planet orbital period [days]
    - e: eccentricity; defaults to circular case e=0
    - i: inclination [radians]; defaults to i=pi/2 edge on
    
    Output: 
    - K: RV semi-amplitude [m/s]
    
    """
    
    MJup = 318 # Earth masses
    f1 = 28.4329 / np.sqrt(1 - e**2)
    f2 = m2 * np.sin(i) / MJup
    f3 = m1**(-2./3) # actually m1+m2 but m2 --> 0
    f4 = (P/365)**(-1./3)
    
    return f1 * f2 * f3 * f4



import numpy as np 
import scipy
import pandas as pd
import random
import astropy 
from numpy.linalg import inv, det, solve, cond
from tqdm import tqdm

import matplotlib.pyplot as plt
import matplotlib

import jax
import jax.numpy as jnp
from jax import grad, jit, vmap

from gaspery import utils

class Strategy: 
    """

    Functions that make strategies, based on user inputs. 

    Attributes:
    - n_obs: number of observations to make; this is a fixed goal [int]
    - start: start time [BJD]
    - offs: all pairs of off-night spans, described by their start/end times [list of two-element lists of floats]
    - dropout: percent of dropout due to weather and other uniformly distributed unfortunate events [float]

    Output:
    - Strategy object, on which the following strategy-building functions can operate.

    """

    def __init__(
        self, n_obs, start, offs=[], dropout=0., **kwargs
    ):
        self.n_obs = n_obs
        self.start = start
        self.offs = offs
        self.dropout = dropout 

    
    def make_t(self, cadence):
        """
        Generate observation times given a number of observations and an average cadence (every X nights)
        
        Input: 
        - Strategy object
        - cadence: time between observations, in days [int]
        
        Output:
        - observation times: ndarray
        
        """
        
        n_obs = self.n_obs
        start = self.start

        ### make a t using n_obs and cadence
        end = start + n_obs * cadence 
        t = np.linspace(start, end, n_obs, endpoint=False)
        
        # add jitter ~ N(0, 1 hr) to timestamps
        t += np.random.normal(0, 1./24)

        return t


    def remove(l,n):
        """
        For the dropout function, randomly remove some fraction of elements.

        Inputs: 
        - l: observation timestamps [np.array]
        - n: fraction to remove [float]

        Output: observation timestamps with random elements removed [np.array]
        """

        return np.sort(random.sample(list(l),int(len(l)*(1-n))))


    def build(self, cadence, twice_flag=False):
        """
        Build a time series of observations, given cadence, off nights, and n_obs.
        Conservative, not greedy.
        Slower than gappy(), so default to gappy() when not using off nights.

        Input:
        - Strategy object
        - cadence: time between observations, in days [int]
        - twice_flag: do we observe twice a day or not? [boolean]

        Output:
        - strat: time series of observations [np.array]

        """

        start = self.start
        offs = self.offs
        dropout = self.dropout
        n_obs = self.n_obs

        strat = []

        n = 0

        ### if I observe 2x per night, it's not as simple as adding 0.5 BJD
        if twice_flag == True:
            #print("For now, we are only doing 2x per day: 8pm local and 6am local")
            morning = False
            while len(strat) < n_obs:
                if morning == False:
                    next = start + n * cadence
                    if next in offs:
                        pass
                    else: 
                        strat.append(next)

                morning = True
                if morning == True:
                    next = start + n * cadence + (5./12) # add 10 hours 
                    if next in offs:
                        pass
                    else: 
                        strat.append(next)

                morning = False

                n += 1
        
        else:

            ### if I have custom off nights
            if len(offs) > 0:
                while len(strat) < n_obs:
                    next = start + n * cadence

                    if next in offs:
                        pass
                    else: 
                        strat.append(next)
                    
                    n += 1
            
            ### else
            elif len(offs) == 0:
                strat = self.make_t(cadence)
        
        # dropout some observations based on dropout
        total_t = Strategy.remove(strat, dropout)
        
        return np.array(strat)
        

    def gappy_greedy(self, cadence):
        """
        Specify how many nights in a row to observe and how many nights in a row to skip,
        eg. input: {nights on, cadence, percentage of completed observations} 
        
        Input: 
        - Strategy object
        - cadence: time between observations, in days [int]

        Output:
        - observation times: ndarray of floats
        
        """
        
        total_t = []
        start = self.start
        offs = self.offs
        dropout = self.dropout
        n_obs = self.n_obs
        n_tot = 0
        n = 0

        if len(offs) > 0:

            # build runway
            runway_end = start + len(offs) + n_obs * cadence
            runway = np.linspace(start, runway_end, int(runway_end - start + 1))

            # remove off nights
            mask = [i for i in runway if i not in offs]

            # keep making observations until you've reached your prescribed budget of observations
            while n_tot < n_obs:

                # allow for multiple spans of off nights
                for off in offs:

                    end = off

                    # rearrange from end = start + n_obs * cadence to get on chunk
                    n = int(np.ceil((end - start)/cadence))

                    try: # if off != offs[-1]: # if there are yet more offs? 
                        t = np.linspace(start, end, n, endpoint=False)

                        # add jitter ~ N(0, 0.5 hr) to timestamps
                        t += np.random.normal(0, 1./48)

                        total_t = np.concatenate([total_t, t])
                        n_remaining = n_obs - len(total_t)

                        # set new start time as next available date
                        start = offs[count+1] # this is wrong

                    except: # if there aren't, then we just straight shot til n_obs is fulfilled
                        #print("exception")
                        end = start + n_remaining * cadence
                        t = np.linspace(start, end, n_remaining, endpoint=False)

                        # add jitter ~ N(0, 0.5 hr) to timestamps
                        t += np.random.normal(0, 1./48)

                        total_t = np.concatenate([total_t, t])

                        # set new start time
                        start = offs[count+1]

                    n_tot = len(total_t)

                    if n_tot >= n_obs:
                        break

                # let's say there's no more offs and yet more observations to make
                # Then, we just straight shot til n_obs is fulfilled          

            # pare down total_t if the last concatenation overshoots n_obs
            # I have logic for dealing with that if I get through all off nights
            # But n_obs gets hit before then, this is to take care of that.
            n_extra = n_tot - n_obs
            if n_extra > 0:
                total_t = total_t[:-n_extra]
        
        else:
            total_t = self.make_t(cadence)
        
        # dropout some observations based on dropout
        total_t = Strategy.remove(total_t, dropout)
        
        return total_t


    def gappy(self, cadence):
        """
        Specify how many nights in a row to observe and how many nights in a row to skip,
        eg. input: {nights on, cadence, percentage of completed observations} 
        
        Input: 
        - Strategy object
        - cadence: time between observations, in days [int]

        Output:
        - observation times: ndarray of floats
        
        """
        
        total_t = []
        start = self.start
        offs = self.offs
        dropout = self.dropout
        n_obs = self.n_obs
        n_tot = 0
        n = 0
        
        if len(offs) > 0:
            # keep making observations until you've reached your prescribed budget of observations
            while n_tot < n_obs:
                # allow for multiple spans of off nights
                for off in offs:

                    end = off[0]

                    # rearrange from end = start + n_obs * cadence to get on chunk
                    n = int(np.ceil((end - start)/cadence))

                    try: # if off != offs[-1]: # if there are yet more offs? 
                        t = np.linspace(start, end, n, endpoint=False)
                        # add jitter ~ N(0, 1 hr) to timestamps
                        t += np.random.normal(0, 1./24)
                        total_t = np.concatenate([total_t, t])
                        n_remaining = n_obs - len(total_t)

                    except: # if there aren't, then we just straight shot til n_obs is fulfilled
                        #print("exception")
                        end = start + n_remaining * cadence
                        t = np.linspace(start, end, n_remaining, endpoint=False)

                        # add jitter ~ N(0, 1 hr) to timestamps
                        t += np.random.normal(0, 1./24)

                        total_t = np.concatenate([total_t, t])


                    # new start time
                    start = off[1]

                    n_tot = len(total_t)

                    if n_tot >= n_obs:
                        break

                # let's say there's no more offs and yet more observations to make
                # Then, we just straight shot til n_obs is fulfilled          

            # pare down total_t if the last concatenation overshoots n_obs
            # I have logic for dealing with that if I get through all off nights
            # But n_obs gets hit before then, this is to take care of that.
            n_extra = n_tot - n_obs
            if n_extra > 0:
                total_t = total_t[:-n_extra]
        
        else:
            total_t = self.make_t(cadence)
        
        # dropout some observations based on dropout
        total_t = Strategy.remove(total_t, dropout)
        
        return total_t

    
    def on_vs_off(self, on, off, twice_flag=False, hours=24):
        """
        Construct observing strategy given on and off nights, plus n_obs and custom off nights.
        Build time series bottom-up.
        
        Inputs: 
        - self: Strategy object, including n_obs and start time/date
        - on: number of consecutive nights of observation [days]
        - off: number of nights to skip [days] (not to be confused with offs list)
        - twice_flag: do we observe twice a day or not? [boolean]
        - hours: number of hours between observations in a single night (applicable only if twice_flag=True) [float]

        Returns: 
        - strat: time series of dates of observations [list of floats]
        
        """
        
        start = self.start
        n_obs = self.n_obs
        offs = self.offs

        strat = []
        curr = start 

        # for each on night, add another day as long as it's not in the offs list
        # then skip by off nights
        if twice_flag==False:

            while len(strat) < n_obs:
                
                # on block
                for i in range(on):

                    add = True
                    # check if in any off day
                    if len(offs) > 0:
                        for custom_off in offs:
                            
                            # if so, tag to don't include
                            if ((curr >= custom_off[0]) & (curr <= custom_off[1])):
                                add = False

                        if add == True:
                            if len(strat) < n_obs:
                                strat.append(curr)

                    elif len(offs) == 0:
                        strat.append(curr)

                    curr += 1

                # off block
                curr += off

        # if we observe twice a day
        elif twice_flag==True:

            while len(strat) < n_obs:
                
                # on block
                for i in range(on):

                    add = True
                    if len(offs) > 0: # if there are manual offs

                        # check if in any off day
                        for custom_off in offs:

                            # if so, tag to don't include
                            if ((curr >= custom_off[0]) & (curr <= custom_off[1])):
                                add = False

                        if add == True:
                            if len(strat) < n_obs:
                                strat.append(curr)
                                    
                        try:
                            curr += hours/24
                        except NameError:
                            print("If you turn on the twice_flag, you need to set hours=N, where N is the number of hours between observations in the same night.")

                        # observe for the second time that night
                        for custom_off in offs:
                            if ((curr >= custom_off[0]) & (curr <= custom_off[1])):
                                add = False

                        if add == True:    
                            if len(strat) < n_obs:
                                strat.append(curr)
                                
                        # cycle back to same time of night the next day
                        curr += (24-hours)/24

                    elif len(offs) == 0:
                        strat.append(curr)
                        curr += (24-hours)/24
                        strat.append(curr)
                        
                # off block
                curr += off
        
        return np.array(strat)


    def on_vs_baseline_balanced(self, on, baseline, perfect_flag=False):
        """
        Construct observing strategy given on nights, baseline, and n_obs.
        Distribute on nights across time series while meeting the prescription.
        
        Inputs: 
        - start: start date [BJD]
        - n_obs: number of observations budgeted for
        - on: number of consecutive nights of observation [days]
        - baseline: overall observing window [days]
        - perfect_flag: if True, only make strategies for combos that have equal numbers of offs in each block
        if False, make strategies for any combo that has off periods = on periods - 1
        
        Returns: 
        - strat: time series of dates of observations [list of floats]
        
        """
        
        start = self.start
        n_obs = self.n_obs 

        temp_start = start
        
        n_on_periods = int(np.ceil(n_obs/on))
        
        # skip combinations that don't necessitate a perfectly balanced strat
        if perfect_flag == True:    
            if (baseline - n_obs) % (n_on_periods - 1) != 0: 
                strat = []
                return strat
    
        n_mixed_periods = int(n_on_periods - 1)
        
        block_length = int(np.floor((baseline - n_obs)/n_mixed_periods))
        
        off_length = block_length - on
        
        on_total = int(n_mixed_periods * on)

        nights_total = int(n_mixed_periods * block_length)
        
        on_residual = n_obs - on_total

        nights_residual = baseline - nights_total
        

        ### construct 'on-masks'
        ons = []
        for i in range(n_mixed_periods):
            on_i = np.arange(temp_start, temp_start + on, 1)
            ons.append(on_i)
                            
            temp_start += on
            
            # minimum off block length
            off1 = np.floor((baseline - n_obs)/n_mixed_periods)
            
            # number of off blocks with an extra night
            off2 = (baseline - n_obs) % n_mixed_periods
            
            if i+1 <= off2:
                temp_start += (off1+1)
            else: 
                temp_start += off1
                            
        ### last on block to top off
        ons.append(np.arange(temp_start, temp_start + on_residual, 1))
        
        ### flatten list
        ons = [item for sublist in ons for item in sublist]
        
        return ons







import numpy as np 
import scipy
import pandas as pd
import random
from itertools import chain
import astropy 
from tinygp import kernels, GaussianProcess
from numpy.linalg import inv, det, solve, cond
from tqdm import tqdm

import matplotlib.pyplot as plt
import matplotlib

import jax
import jax.numpy as jnp
from jax import grad, jit, vmap


class Star(object): 
    """
    Star objects contain the target star's properties, to be fed into the cov_matrix_jax() function for calculating the covariance matrix.

    Attributes: 
    - sigma_wn_rv: white/photon noise amplitude [cm/s]; free param taken from Langellier et al 2020
    - Tau: active region lifetime [days]; free param taken from Langellier et al 2020
    - eta: smoothing parameter; free param taken from Langellier et al 2020
    - Prot: rotation period [days]; free param taken from Langellier et al 2020
    - sigma_qp_rv: correlated noise amplitude [cm/s]; free param taken from Langellier et al 2020

    """

    def __init__(
        self, sigma_wn_rv, Tau=None, eta=None, Prot=None, sigma_qp_rv=None, **kwargs 
    ):
        self.sigma_wn_rv = sigma_wn_rv
        try:
            self.Tau = Tau
            self.eta = eta
            self.Prot = Prot
            self.sigma_qp_rv = sigma_qp_rv
        except:
            pass

    """
    def __init__(
        self, sigma_wn_rv, kernel=None, **kwargs 
    ):
        self.sigma_wn_rv = sigma_wn_rv
        try:
            self.kernel
        except:
            pass
    """

    def param_list(self):
        """
        Make list of params based on Star object attributes to feed into cov_matrix_jax()

        Input:
        - Star object with attributes from __init__()
        Return:
        - Params: list of parameters to feed into cov_matrix_jax(), for either white or correlated noise case

        """

        # if correlated noise 
        try:
            params = [self.sigma_wn_rv, self.Tau, self.eta, self.Prot, self.sigma_qp_rv]
        # elif white noise only
        except:
            params = [self.sigma_wn_rv]

        return params


    def cov_matrix_general(self, t, kernel=None):
        """
        Build a covariance matrix that will be used in the calculation of the Fisher Information Matrix, using a generalized GP kernel from the tinygp package.
        
        Inputs:
        - self: Star object
        - t: time series of length N observations; np.array [day]
        - kernel: kernel object from tinygp.kernels.Kernel class

        Outputs:
        - N by N matrix of covariance elements following Equations 1 & 2 of Langellier et al 2020
        
        """

        # if we are in correlated noise regime, using a quasi-periodic Gaussian Process kernel
        #if all([self.sigma_wn_rv, self.Tau, self.eta, self.Prot, self.sigma_qp_rv]):
        if kernel != None:
            sigma_wn_rv, Tau, eta, Prot, sigma_qp_rv = self.sigma_wn_rv, self.Tau, self.eta, self.Prot, self.sigma_qp_rv

            # build correlated noise part of the covariance matrix using the tinygp kernel and observation strategy
            k = kernel(t, t)

            # add white noise to generate the full covariance matrix
            K = k + sigma_wn_rv**2 * jnp.diag(np.ones(len(t)))
            
            return K

        # if we are in white noise regime exclusively
        #elif all([self.sigma_wn_rv]): 
        elif kernel == None:
            sigma_wn_rv = self.sigma_wn_rv**2 
            sigma = np.diag(sigma_wn_rv * np.ones(len(t)))

            return sigma


    def cov_matrix(self, t):
        """
        Build a covariance matrix that will be used in the calculation of the Fisher Information Matrix, using a quasi-periodic GP kernel.
        
        Inputs:
        - self: Star object
        - t: time series of length N observations; np.array [day]

        Outputs:
        - N by N matrix of covariance elements following Equations 1 & 2 of Langellier et al 2020
        
        """
        
        sigma_wn_rv = self.sigma_wn_rv**2 
        white_noise = np.diag(sigma_wn_rv * np.ones(len(t)))

        # if we are in correlated noise regime, using a quasi-periodic Gaussian Process kernel
        if all([self.sigma_wn_rv, self.Tau, self.eta, self.Prot, self.sigma_qp_rv]):
            sigma_wn_rv, Tau, eta, Prot, sigma_qp_rv = self.sigma_wn_rv, self.Tau, self.eta, self.Prot, self.sigma_qp_rv

            # create N by N matrix, where N is length of observations time series
            k = jnp.zeros((len(t),len(t)))
            #print("strat: ", t)
            for i in range(len(t)):
                for j in range(len(t)):
                    term1 = ((t[i]-t[j])**2)/(2*Tau**2)
                    term2 = (1/(2*eta**2)) * (jnp.sin(jnp.pi * (t[i] - t[j])/Prot))**2
                    arg = -term1 - term2
                    #k[i][j] = jnp.exp(arg)
                    k = jnp.exp(arg)
                    #k = k.at[i]
                    #x = x.at[idx].set(y)
            
            K = sigma_qp_rv**2 * k + sigma_wn_rv**2 * jnp.diag(np.ones(len(t)))
            #print("shape: ", K.shape)
            
            return K

        # if we are in white noise regime
        elif all([self.sigma_wn_rv]): 
            sigma_wn_rv = self.sigma_wn_rv**2 
            sigma = np.diag(sigma_wn_rv * np.ones(len(t)))

            return sigma

        # else, we are not in a valid regime
        else:
            raise AttributeError('Please input at least sigma_wn_rv for photon noise.')


class Planets(object):
    """
    Planet objects contain the target system's planet properties, to be fed into the clam_jax_fim() function for calculating Fisher Information.
    Multiple planets are allowed.

    Attributes:
    - K: RV semi-amplitude [cm/s]
    - p: planet orbital period [days]
    - T0: planet central transit time [BJD]

    """ 

    def __init__(
        self, K, p, T0, **kwargs
    ):
        self.K = K
        self.p = p
        self.T0 = T0


    def theta_list(self):
        """
        Make list of params based on Planets object attributes to feed into Fisher Info calculation machinery

        Input:
        - Planets object with attributes from __init__()
        Return:
        - Theta: list of parameters to feed into clam_jax_fim()

        """

        theta = [self.K, self.p, self.T0]

        return theta


def cov_matrix_jax(t, sigma_wn_rv, params=[]):
    """
    Build a covariance matrix, Sigma, that will be used in the calculation of the Fisher Information Matrix.
    Deprecated bc incompatibility with object-oriented framework.
    
    Inputs:
    - t: time series of length N observations; np.array [day]
    - sigma_wn_rv: white noise amplitude; free param taken from Langellier et al 2020
    - params: list of stellar correlated noise parameters
        - Tau: active region lifetime [days]; free param taken from Langellier et al 2020
        - eta: smoothing parameter; free param taken from Langellier et al 2020
        - Prot: rotation period [days]; free param taken from Langellier et al 2020
        - sigma_qp_rv: correlated noise amplitude; free param taken from Langellier et al 2020
    
    Outputs:
    - N by N matrix of covariance elements following Equations 1 & 2 of Langellier et al 2020
    
    """
        
    # if we are in correlated noise regime, using a quasi-periodic kernel
    if len(params) != 0:
        Tau, eta, Prot, sigma_qp_rv = params[0], params[1], params[2], params[3]

        # create N by N matrix, where N is length of observations time series
        k = jnp.zeros((len(t),len(t)))
        
        for i in range(len(t)):
            for j in range(len(t)):
                term1 = ((t[i]-t[j])**2)/(2*Tau**2)
                term2 = (1/(2*eta**2)) * (jnp.sin(jnp.pi * (t[i] - t[j])/Prot))**2
                arg = -term1 - term2
                k = jnp.exp(arg)
        
        K = sigma_qp_rv**2 * k + sigma_wn_rv**2 * jnp.diag(np.ones(len(t)))
        
        return K

    # else, we are in strictly white noise regime
    elif len(params) == 0: 
        sigma_wn_rv = sigma_wn_rv**2 
        sigma = np.diag(sigma_wn_rv * np.ones(len(t)))

        return sigma


@jax.jit
def clam_jax_fim(t, sigma, theta): 
    """
    Calculate the generalized Fisher Information Matrix using JAX Jacobian.
    Generalizable to arbitrary parameters.
    Now, with second term for correlated noise. 
    
    Inputs: 
    - t: time series of length N observations; np.array [day]
    - sigma: RV measurement uncertainties associated with each observation; np.array of length N [cm/s]
    - theta: planet orbital parameters; must be flattened list if multiple planets; np.array
        - K: RV semi-amplitude [cm/s]
        - P: planet period [days]
        - T0: mean transit time [day]

    Output:
    - Fisher Information Matrix: len(theta)xlen(theta) matrix; np.array
    
    """
    
    def inner(params):
        return model_jax(t, params)
    
    # add jitter
    sigma += 1e-6 

    # take inverse of covariance matrix
    factor = jnp.linalg.solve(sigma, jnp.identity(len(sigma))) 
    
    # calculate the Jacobian   
    J = jax.jacobian(inner)(theta)

    return J.T @ factor @ J


def model_jax(t, flat_theta): 

    """
    JAX-enabled radial velocity model for multi-planet system.
    Generalized to take flattened list of thetas of arbitrary number of planets.

    Inputs: 
    - t: time series of length N observations; np.array [day]
    - flat_theta: flattened list of lists of [K, P, T0], where:
        - K: RV semi-amplitude [cm/s]
        - P: planet period [days]
        - T0: mean transit time [day]

    Returns: 
    - rv_total: np.array of RV semi-amplitudes

    """
    
    rv_total = np.zeros(len(t))
    #flat_theta = list(chain.from_iterable(thetas))
    
    counter = 0
    while counter < len(flat_theta):  
        K, P, T0 = flat_theta[counter], flat_theta[counter+1], flat_theta[counter+2]
        arg = (2*jnp.pi/P)*(t-T0)
        rv = -K * jnp.sin(arg)
        rv_total += rv
        
        counter += 3
        
    return rv_total


def model_jax_multi(t, theta): 

    """
    JAX-enabled radial velocity model for multi-planet system
    For testing on multi-planet system to see if generalized function works correctly.
    
    Inputs: 
    - t: time series of length N observations; np.array [day]
    - thetas: list of lists of [K, P, T0], where:
        - K: RV semi-amplitude [cm/s]
        - P: planet period [days]
        - T0: mean transit time [day]

    Returns: 
    - rv_total: np.array of RV semi-amplitudes

    """
    
    K1, P1, T0_1, K2, P2, T0_2 = theta[0], theta[1], theta[2], theta[3], theta[4], theta[5]
    
    arg1 = (2*jnp.pi/P1)*(t-T0_1)
    rv1 = -K1 * jnp.sin(arg1)
    
    arg2 = (2*jnp.pi/P2)*(t-T0_2)
    rv2 = -K2 * jnp.sin(arg2)

    rv_total = rv1 + rv2
    
    return rv_total



"""
# -*- coding: utf-8 -*-

__all__ = ["__version__"]

#from . import blah, blah, blah
# from .blah import * or something specific

__author__ = "Christopher Lam"
__email__ = "c.lam@ufl.com"
__license__ = "MIT License"
__description__ = "Fisher Information-based radial velocity observation scheduling"
"""


from setuptools import setup, find_packages

setup(
    name = "gaspery",
    version = "0.2.1", 
    #packages = find_packages(),
    packages = ['gaspery'],
    package_dir={"":"src"},
    author = 'Chris Lam',
    author_email = 'c.lam@ufl.edu',
    description = 'Fisher Information-based radial velocity observation scheduling',
    license = 'MIT License'
    #install_requires = [
    #    'tinygp',
    #    'numpy'
    #]
)
